@@ -2,7 +2,7 @@
 
 # bounced.pl - This script runs as a daemon ; it does the incoming 
 # non-delivery reports analysis and storage
-# RCS Identication ; $Revision: 6184 $ ; $Date: 2009-09-04 14:57:30 +0200 (ven 04 sep 2009) $ 
+# RCS Identication ; $Revision: 7119 $ ; $Date: 2011-06-16 05:05:30 +0200 (jeu 16 jun 2011) $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -496,8 +496,8 @@ while (!$end) {
 	    ## Bounce directory
 	    if (! -d $bounce_dir) {
 		unless (mkdir $bounce_dir, 0777) {
-		    &List::send_notify_to_listmaster('intern_error',$Conf{'domain'},{'error' => "Failed to list create bounce directory $bounce_dir"});
-		    &do_log('err', 'Could not create %s: %s bounced die, check bounce-path in wwsympa.conf', $bounce_dir, $!);
+		    &List::send_notify_to_listmaster('bounce_intern_error',$Conf{'domain'},{'error' => "Failed to list create bounce directory $bounce_dir"});
+		    &do_log('err', 'Could not create %s: %s bounced dir, check bounce_path in wwsympa.conf', $bounce_dir, $!);
 		    exit;
 		} 
 	    }
@@ -590,6 +590,7 @@ sub store_bounce {
 	return undef;
     }
     print ARC <BOUNCE>;
+    close ARC;
     close BOUNCE; 
 }
 
