@@ -1,5 +1,5 @@
 # bounce-lib.pl - This module includes functions for analysing non-delivery reports
-# RCS Identication ; $Revision: 5958 $ ; $Date: 2009-07-10 16:44:46 +0200 (ven 10 jui 2009) $ 
+# RCS Identication ; $Revision: 6559 $ ; $Date: 2010-06-22 09:48:56 +0200 (mar 22 jun 2010) $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -164,7 +164,7 @@ sub anabounce {
     my %info;
     my ($qmail, $type_9, $type_18, $exchange, $ibm_vm, $lotus, $sendmail_5, $yahoo, $type_21, $exim, $vines,
 	$mercury_143, $altavista, $mercury_131, $type_31, $type_32,$exim_173, $type_38, $type_39,
-	$type_40, $pmdf, $following_recipients, $postfix);
+	$type_40, $pmdf, $following_recipients, $postfix, $groupwise7);
 
     ## Le champ separateur de paragraphe est un ensemble
     ## de lignes vides
@@ -196,8 +196,9 @@ sub anabounce {
 		}
 
 		## Le champ From:
-		$champ{from} =~ /([^\s<]+@[^\s>]+)/;
-		$$from = $1;
+		if($champ{from} =~ /([^\s<]+@[^\s>]+)/){
+		    $$from = $1;
+		}
 		
 	    }
 	    local $/ = '';
@@ -953,6 +954,28 @@ sub anabounce {
 		 }
 	     }
 	     local $/ = '';
+	 }elsif ( /^The message that you sent was undeliverable to the following:/ ) {
+
+             $groupwise7 = 1;
+
+         }elsif ($groupwise7) {
+
+             undef $groupwise7;
+
+	     ## Parcour du paragraphe
+	     my @paragraphe = split /\n/, $_;
+	     local $/ = "\n";
+	     foreach (@paragraphe) {
+
+		if ( /^\s+(\S*) \((.+)\)/ ) {
+
+		     $info{$1}{error} = $2;
+
+		}
+	     }
+
+	     local $/ = '';
+
 	 ## Wanadoo    
 	 }elsif (/^(\S+); Action: Failed; Status: \d.\d.\d \((.*)\)/m) {
 	     $info{$1}{error} = $2;
