@@ -1,5 +1,5 @@
 # Conf.pm - This module does the sympa.conf and robot.conf parsing
-# RCS Identication ; $Revision: 6669 $ ; $Date: 2010-09-02 11:40:22 +0200 (jeu 02 sep 2010) $ 
+# RCS Identication ; $Revision: 7014 $ ; $Date: 2011-02-02 16:36:47 +0100 (mer 02 fév 2011) $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -1109,7 +1109,7 @@ sub _load_auth {
 					    'ldap_ssl_ciphers' => '[\w:]+',
 					    'force_email_verify' => '1',
 					    'internal_email_by_netid' => '1',
-					    'netid_http_header' => '\w+',
+					    'netid_http_header' => '[\w\-\.]+',
 					},
 			  'authentication_info_url' => 'http(s)?:/.*'
 			  );
@@ -1203,6 +1203,13 @@ sub _load_auth {
 		  $Conf{'generic_sso_id'}{$robot}{$current_paragraph->{'service_id'}} =  $#paragraphs+1 ; 
 		  $current_paragraph->{'ldap_scope'} ||= 'sub'; ## Force the default scope because '' is interpreted as 'base'
 		  $current_paragraph->{'http_header_value_separator'} ||= ';'; ## default value for http_header_value_separator is ';'
+
+		  ## CGI.pm changes environment variable names ('-' => '_')
+		  ## declared environment variable names needs to be transformed accordingly
+		  foreach my $parameter ('http_header_list','email_http_header','netid_http_header') {
+		      $current_paragraph->{$parameter} =~ s/\-/\_/g if (defined $current_paragraph->{$parameter});
+		  }
+
 		}elsif($current_paragraph->{'auth_type'} eq 'ldap') {
 		    $Conf{'ldap'}{$robot}  ++ ;
 		    $Conf{'use_passwd'}{$robot} = 1;
