@@ -1,5 +1,5 @@
 # Lock.pm - This module includes Sympa locking functions
-#<!-- RCS Identication ; $Revision: 6559 $ ; $Date: 2010-06-22 09:48:56 +0200 (mar 22 jun 2010) $ --> 
+#<!-- RCS Identication ; $Revision: 6754 $ ; $Date: 2010-11-17 08:50:52 +0100 (mer 17 nov 2010) $ --> 
 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
@@ -342,12 +342,12 @@ sub _lock_nfs {
     my $nfs_lock = undef;
     my $FH = undef;
     
-    if ($nfs_lock = new File::NFSLock {
+    if ($nfs_lock = File::NFSLock->new( {
 	file      => $lock_file,
 	lock_type => $operation|LOCK_NB,
 	blocking_timeout   => $hold,
 	stale_lock_timeout => $timeout,
-    }) {
+    })) {
 	## Read access to prevent "Bad file number" error on Solaris
 	$FH = new FileHandle;
 	unless (open $FH, $open_mode.$lock_file) {
