@@ -1,5 +1,5 @@
 # Upgrade.pm - This module gathers all subroutines used to upgrade Sympa data structures
-#<!-- RCS Identication ; $Revision: 6546 $ --> 
+#<!-- RCS Identication ; $Revision: 7055 $ --> 
 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
@@ -790,7 +790,7 @@ sub probe_db {
 							     'remote_addr_one_time_ticket' => 'varchar(60)',
 							     'status_one_time_ticket' => 'varchar(60)'},
 				 'bulkmailer_table' => {'messagekey_bulkmailer' => 'varchar(80)',
-							'messageid_bulkmailer' => 'varchar(100)',
+							'messageid_bulkmailer' => 'varchar(200)',
 							'packetid_bulkmailer' => 'varchar(33)',
 							'receipients_bulkmailer' => 'text',
 							'returnpath_bulkmailer' => 'varchar(100)',
@@ -804,7 +804,7 @@ sub probe_db {
 							'delivery_date_bulkmailer' => 'int(11)',
 							'lock_bulkmailer' => 'varchar(30)'},
 				 'bulkspool_table' => {'messagekey_bulkspool' => 'varchar(33)',
-						       'messageid_bulkspool' => 'varchar(100)',
+						       'messageid_bulkspool' => 'varchar(200)',
 						       'message_bulkspool' => 'longtext',
 						       'lock_bulkspool' => 'int(1)',
 						       'dkim_privatekey_bulkspool' => 'varchar(1000)',
@@ -1206,7 +1206,7 @@ sub probe_db {
 		}
 		
 		## Change DB types if different and if update_db_types enabled
-		if ($Conf::Conf{'update_db_field_types'} eq 'auto') {
+		if ($Conf::Conf{'update_db_field_types'} eq 'auto' && $Conf::Conf{'db_type'} ne 'SQLite') {
 		    unless (&check_db_field_type(effective_format => $real_struct{$t}{$f},
 						 required_format => $db_struct{$Conf::Conf{'db_type'}}{$t}{$f})) {
 			push @report, sprintf('Field \'%s\'  (table \'%s\' ; database \'%s\') does NOT have awaited type (%s). Attempting to change it...', 
