@@ -1,5 +1,5 @@
 # admin.pm - This module includes administrative function for the lists
-# RCS Identication ; $Revision: 6678 $ ; $Date: 2010-09-10 12:05:21 +0200 (ven 10 sep 2010) $ 
+# RCS Identication ; $Revision: 7122 $ ; $Date: 2011-06-18 04:17:17 +0200 (sam 18 jun 2011) $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -945,7 +945,7 @@ sub clone_list_as_empty {
 	    }
     }
     # copy optional files
-    foreach my $file ('message.footer','message.header','info') {
+    foreach my $file ('message.footer','message.header','info','homepage') {
 	if (-f $list->{'dir'}.'/'.$file) {
 	    unless (&File::Copy::copy ($list->{'dir'}.'/'.$file, $new_dir.'/'.$file)) {
 		&do_log('err','Admin::clone_list_as_empty : failed to copy %s : %s',$new_dir.'/'.$file, $!);
@@ -1139,7 +1139,7 @@ sub install_aliases {
 	 system ("$alias_manager add $list->{'name'} $list->{'admin'}{'host'}") ;
 	 my $status = $? / 256;
 	 if ($status == 0) {
-	     &do_log('err','admin::install_aliases : Aliases installed successfully') ;
+	     &do_log('info','admin::install_aliases : Aliases installed successfully') ;
 	     $alias_installed = 1;
 	 }elsif ($status == 1) {
 	     &do_log('err','admin::install_aliases : Configuration file %s has errors', Sympa::Constants::CONFIG);
