@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 # sympa.pl - This script is the main one ; it runs as a daemon and does
 # the messages/commands processing
-# RCS Identication ; $Revision: 6544 $ ; $Date: 2010-06-21 17:31:29 +0200 (lun 21 jun 2010) $ 
+# RCS Identication ; $Revision: 6972 $ ; $Date: 2011-01-17 12:14:13 +0100 (lun 17 jan 2011) $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -1865,7 +1865,7 @@ sub DoMessage{
 
     if ($max_size && $message->{'size'} > $max_size) {
 		&do_log('info', 'sympa::DoMessage(): Message for %s from %s rejected because too large (%d > %d)', $listname, $sender, $message->{'size'}, $max_size);
-		&report::reject_report_msg('user','message_too_large',$sender,{'message' => $message},$robot,$msg_string,$list);
+		&report::reject_report_msg('user','message_too_large',$sender,{'msg_size' => int($message->{'size'} / 1024),'max_size' => int($max_size / 1024)},$robot,'',$list);
 		&Log::db_log({'robot' => $robot,'list' => $list->{'name'},'action' => 'DoMessage','parameters' => "$which,$messageid,$robot",'target_email' => '','msg_id' => $messageid,'status' => 'error','error_type' => 'message_too_large','user_email' => $sender,'client' => $ip,'daemon' => $daemon_name});
 		return undef;
    }
